Class: Google::Cloud::Bigquery::AnalyticsHub::V1::DeleteListingRequest
- Inherits:
-
Object
- Object
- Google::Cloud::Bigquery::AnalyticsHub::V1::DeleteListingRequest
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/bigquery/analyticshub/v1/analyticshub.rb
Overview
Message for deleting a listing.
Instance Attribute Summary collapse
-
#delete_commercial ⇒ ::Boolean
Optional.
-
#name ⇒ ::String
Required.
Instance Attribute Details
#delete_commercial ⇒ ::Boolean
Returns Optional. If the listing is commercial then this field must be set to true, otherwise a failure is thrown. This acts as a safety guard to avoid deleting commercial listings accidentally.
1094 1095 1096 1097 |
# File 'proto_docs/google/cloud/bigquery/analyticshub/v1/analyticshub.rb', line 1094 class DeleteListingRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#name ⇒ ::String
Returns Required. Resource name of the listing to delete.
e.g. projects/myproject/locations/us/dataExchanges/123/listings/456.
1094 1095 1096 1097 |
# File 'proto_docs/google/cloud/bigquery/analyticshub/v1/analyticshub.rb', line 1094 class DeleteListingRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |