Class: Google::Cloud::Bigquery::AnalyticsHub::V1::StoredProcedureConfig

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/bigquery/analyticshub/v1/analyticshub.rb

Overview

Stored procedure configuration, used to configure stored procedure sharing on linked dataset.

Defined Under Namespace

Modules: StoredProcedureType

Instance Attribute Summary collapse

Instance Attribute Details

#allowed_stored_procedure_types::Array<::Google::Cloud::Bigquery::AnalyticsHub::V1::StoredProcedureConfig::StoredProcedureType> (readonly)

Returns Output only. Types of stored procedure supported to share.

Returns:



748
749
750
751
752
753
754
755
756
757
758
759
760
# File 'proto_docs/google/cloud/bigquery/analyticshub/v1/analyticshub.rb', line 748

class StoredProcedureConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Enum to specify the type of stored procedure to share.
  module StoredProcedureType
    # Default value. This value is unused.
    STORED_PROCEDURE_TYPE_UNSPECIFIED = 0

    # SQL stored procedure.
    SQL_PROCEDURE = 1
  end
end

#enabled::Boolean

Returns Optional. If true, enable sharing of stored procedure.

Returns:

  • (::Boolean)

    Optional. If true, enable sharing of stored procedure.



748
749
750
751
752
753
754
755
756
757
758
759
760
# File 'proto_docs/google/cloud/bigquery/analyticshub/v1/analyticshub.rb', line 748

class StoredProcedureConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Enum to specify the type of stored procedure to share.
  module StoredProcedureType
    # Default value. This value is unused.
    STORED_PROCEDURE_TYPE_UNSPECIFIED = 0

    # SQL stored procedure.
    SQL_PROCEDURE = 1
  end
end