Class: Google::Cloud::Bigquery::AnalyticsHub::V1::Listing::BigQueryDatasetSource
- Inherits:
-
Object
- Object
- Google::Cloud::Bigquery::AnalyticsHub::V1::Listing::BigQueryDatasetSource
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/bigquery/analyticshub/v1/analyticshub.rb
Overview
A reference to a shared dataset. It is an existing BigQuery dataset with a collection of objects such as tables and views that you want to share with subscribers. When subscriber's subscribe to a listing, Analytics Hub creates a linked dataset in the subscriber's project. A Linked dataset is an opaque, read-only BigQuery dataset that serves as a symbolic link to a shared dataset.
Defined Under Namespace
Classes: Replica, RestrictedExportPolicy, SelectedResource
Instance Attribute Summary collapse
-
#dataset ⇒ ::String
Optional.
-
#effective_replicas ⇒ ::Array<::Google::Cloud::Bigquery::AnalyticsHub::V1::Listing::BigQueryDatasetSource::Replica>
readonly
Output only.
-
#replica_locations ⇒ ::Array<::String>
Optional.
-
#restricted_export_policy ⇒ ::Google::Cloud::Bigquery::AnalyticsHub::V1::Listing::BigQueryDatasetSource::RestrictedExportPolicy
Optional.
-
#selected_resources ⇒ ::Array<::Google::Cloud::Bigquery::AnalyticsHub::V1::Listing::BigQueryDatasetSource::SelectedResource>
Optional.
Instance Attribute Details
#dataset ⇒ ::String
Returns Optional. Resource name of the dataset source for this listing.
e.g. projects/myproject/datasets/123.
526 527 528 529 530 531 532 533 534 535 536 537 538 539 540 541 542 543 544 545 546 547 548 549 550 551 552 553 554 555 556 557 558 559 560 561 562 563 564 565 566 567 568 569 570 571 572 573 574 575 576 577 578 579 580 581 582 583 584 585 586 587 588 589 590 591 592 593 594 595 596 597 598 599 600 601 602 603 604 605 606 607 608 609 610 611 612 |
# File 'proto_docs/google/cloud/bigquery/analyticshub/v1/analyticshub.rb', line 526 class BigQueryDatasetSource include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Resource in this dataset that is selectively shared. # @!attribute [rw] table # @return [::String] # Optional. Format: # For table: # `projects/{projectId}/datasets/{datasetId}/tables/{tableId}` # Example:"projects/test_project/datasets/test_dataset/tables/test_table" # # Note: The following fields are mutually exclusive: `table`, `routine`. If a field in that set is populated, all other fields in the set will automatically be cleared. # @!attribute [rw] routine # @return [::String] # Optional. Format: # For routine: # `projects/{projectId}/datasets/{datasetId}/routines/{routineId}` # Example:"projects/test_project/datasets/test_dataset/routines/test_routine" # # Note: The following fields are mutually exclusive: `routine`, `table`. If a field in that set is populated, all other fields in the set will automatically be cleared. class SelectedResource include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Restricted export policy used to configure restricted export on linked # dataset. # @!attribute [rw] enabled # @return [::Google::Protobuf::BoolValue] # Optional. If true, enable restricted export. # @!attribute [rw] restrict_direct_table_access # @return [::Google::Protobuf::BoolValue] # Optional. If true, restrict direct table access (read # api/tabledata.list) on linked table. # @!attribute [rw] restrict_query_result # @return [::Google::Protobuf::BoolValue] # Optional. If true, restrict export of query result derived from # restricted linked dataset table. class RestrictedExportPolicy include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Represents the state of a replica of a shared dataset. # It includes the geographic location of the replica and # system-computed, output-only fields indicating its replication state and # whether it is the primary replica. # @!attribute [r] location # @return [::String] # Output only. The geographic location where the replica resides. See # [BigQuery locations](https://cloud.google.com/bigquery/docs/locations) # for supported locations. Eg. "us-central1". # @!attribute [r] replica_state # @return [::Google::Cloud::Bigquery::AnalyticsHub::V1::Listing::BigQueryDatasetSource::Replica::ReplicaState] # Output only. Assigned by Analytics Hub based on real BigQuery # replication state. # @!attribute [r] primary_state # @return [::Google::Cloud::Bigquery::AnalyticsHub::V1::Listing::BigQueryDatasetSource::Replica::PrimaryState] # Output only. Indicates that this replica is the primary replica. class Replica include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Replica state of the shared dataset. module ReplicaState # Default value. This value is unused. REPLICA_STATE_UNSPECIFIED = 0 # The replica is backfilled and ready to use. READY_TO_USE = 1 # The replica is unavailable, does not exist, or has not been # backfilled yet. UNAVAILABLE = 2 end # Primary state of the replica. Set only for the primary replica. module PrimaryState # Default value. This value is unused. PRIMARY_STATE_UNSPECIFIED = 0 # The replica is the primary replica. PRIMARY_REPLICA = 1 end end end |
#effective_replicas ⇒ ::Array<::Google::Cloud::Bigquery::AnalyticsHub::V1::Listing::BigQueryDatasetSource::Replica> (readonly)
Returns Output only. Server-owned effective state of replicas. Contains both primary and secondary replicas. Each replica includes a system-computed (output-only) state and primary designation.
526 527 528 529 530 531 532 533 534 535 536 537 538 539 540 541 542 543 544 545 546 547 548 549 550 551 552 553 554 555 556 557 558 559 560 561 562 563 564 565 566 567 568 569 570 571 572 573 574 575 576 577 578 579 580 581 582 583 584 585 586 587 588 589 590 591 592 593 594 595 596 597 598 599 600 601 602 603 604 605 606 607 608 609 610 611 612 |
# File 'proto_docs/google/cloud/bigquery/analyticshub/v1/analyticshub.rb', line 526 class BigQueryDatasetSource include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Resource in this dataset that is selectively shared. # @!attribute [rw] table # @return [::String] # Optional. Format: # For table: # `projects/{projectId}/datasets/{datasetId}/tables/{tableId}` # Example:"projects/test_project/datasets/test_dataset/tables/test_table" # # Note: The following fields are mutually exclusive: `table`, `routine`. If a field in that set is populated, all other fields in the set will automatically be cleared. # @!attribute [rw] routine # @return [::String] # Optional. Format: # For routine: # `projects/{projectId}/datasets/{datasetId}/routines/{routineId}` # Example:"projects/test_project/datasets/test_dataset/routines/test_routine" # # Note: The following fields are mutually exclusive: `routine`, `table`. If a field in that set is populated, all other fields in the set will automatically be cleared. class SelectedResource include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Restricted export policy used to configure restricted export on linked # dataset. # @!attribute [rw] enabled # @return [::Google::Protobuf::BoolValue] # Optional. If true, enable restricted export. # @!attribute [rw] restrict_direct_table_access # @return [::Google::Protobuf::BoolValue] # Optional. If true, restrict direct table access (read # api/tabledata.list) on linked table. # @!attribute [rw] restrict_query_result # @return [::Google::Protobuf::BoolValue] # Optional. If true, restrict export of query result derived from # restricted linked dataset table. class RestrictedExportPolicy include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Represents the state of a replica of a shared dataset. # It includes the geographic location of the replica and # system-computed, output-only fields indicating its replication state and # whether it is the primary replica. # @!attribute [r] location # @return [::String] # Output only. The geographic location where the replica resides. See # [BigQuery locations](https://cloud.google.com/bigquery/docs/locations) # for supported locations. Eg. "us-central1". # @!attribute [r] replica_state # @return [::Google::Cloud::Bigquery::AnalyticsHub::V1::Listing::BigQueryDatasetSource::Replica::ReplicaState] # Output only. Assigned by Analytics Hub based on real BigQuery # replication state. # @!attribute [r] primary_state # @return [::Google::Cloud::Bigquery::AnalyticsHub::V1::Listing::BigQueryDatasetSource::Replica::PrimaryState] # Output only. Indicates that this replica is the primary replica. class Replica include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Replica state of the shared dataset. module ReplicaState # Default value. This value is unused. REPLICA_STATE_UNSPECIFIED = 0 # The replica is backfilled and ready to use. READY_TO_USE = 1 # The replica is unavailable, does not exist, or has not been # backfilled yet. UNAVAILABLE = 2 end # Primary state of the replica. Set only for the primary replica. module PrimaryState # Default value. This value is unused. PRIMARY_STATE_UNSPECIFIED = 0 # The replica is the primary replica. PRIMARY_REPLICA = 1 end end end |
#replica_locations ⇒ ::Array<::String>
Returns Optional. A list of regions where the publisher has created shared dataset replicas.
526 527 528 529 530 531 532 533 534 535 536 537 538 539 540 541 542 543 544 545 546 547 548 549 550 551 552 553 554 555 556 557 558 559 560 561 562 563 564 565 566 567 568 569 570 571 572 573 574 575 576 577 578 579 580 581 582 583 584 585 586 587 588 589 590 591 592 593 594 595 596 597 598 599 600 601 602 603 604 605 606 607 608 609 610 611 612 |
# File 'proto_docs/google/cloud/bigquery/analyticshub/v1/analyticshub.rb', line 526 class BigQueryDatasetSource include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Resource in this dataset that is selectively shared. # @!attribute [rw] table # @return [::String] # Optional. Format: # For table: # `projects/{projectId}/datasets/{datasetId}/tables/{tableId}` # Example:"projects/test_project/datasets/test_dataset/tables/test_table" # # Note: The following fields are mutually exclusive: `table`, `routine`. If a field in that set is populated, all other fields in the set will automatically be cleared. # @!attribute [rw] routine # @return [::String] # Optional. Format: # For routine: # `projects/{projectId}/datasets/{datasetId}/routines/{routineId}` # Example:"projects/test_project/datasets/test_dataset/routines/test_routine" # # Note: The following fields are mutually exclusive: `routine`, `table`. If a field in that set is populated, all other fields in the set will automatically be cleared. class SelectedResource include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Restricted export policy used to configure restricted export on linked # dataset. # @!attribute [rw] enabled # @return [::Google::Protobuf::BoolValue] # Optional. If true, enable restricted export. # @!attribute [rw] restrict_direct_table_access # @return [::Google::Protobuf::BoolValue] # Optional. If true, restrict direct table access (read # api/tabledata.list) on linked table. # @!attribute [rw] restrict_query_result # @return [::Google::Protobuf::BoolValue] # Optional. If true, restrict export of query result derived from # restricted linked dataset table. class RestrictedExportPolicy include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Represents the state of a replica of a shared dataset. # It includes the geographic location of the replica and # system-computed, output-only fields indicating its replication state and # whether it is the primary replica. # @!attribute [r] location # @return [::String] # Output only. The geographic location where the replica resides. See # [BigQuery locations](https://cloud.google.com/bigquery/docs/locations) # for supported locations. Eg. "us-central1". # @!attribute [r] replica_state # @return [::Google::Cloud::Bigquery::AnalyticsHub::V1::Listing::BigQueryDatasetSource::Replica::ReplicaState] # Output only. Assigned by Analytics Hub based on real BigQuery # replication state. # @!attribute [r] primary_state # @return [::Google::Cloud::Bigquery::AnalyticsHub::V1::Listing::BigQueryDatasetSource::Replica::PrimaryState] # Output only. Indicates that this replica is the primary replica. class Replica include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Replica state of the shared dataset. module ReplicaState # Default value. This value is unused. REPLICA_STATE_UNSPECIFIED = 0 # The replica is backfilled and ready to use. READY_TO_USE = 1 # The replica is unavailable, does not exist, or has not been # backfilled yet. UNAVAILABLE = 2 end # Primary state of the replica. Set only for the primary replica. module PrimaryState # Default value. This value is unused. PRIMARY_STATE_UNSPECIFIED = 0 # The replica is the primary replica. PRIMARY_REPLICA = 1 end end end |
#restricted_export_policy ⇒ ::Google::Cloud::Bigquery::AnalyticsHub::V1::Listing::BigQueryDatasetSource::RestrictedExportPolicy
Returns Optional. If set, restricted export policy will be propagated and enforced on the linked dataset.
526 527 528 529 530 531 532 533 534 535 536 537 538 539 540 541 542 543 544 545 546 547 548 549 550 551 552 553 554 555 556 557 558 559 560 561 562 563 564 565 566 567 568 569 570 571 572 573 574 575 576 577 578 579 580 581 582 583 584 585 586 587 588 589 590 591 592 593 594 595 596 597 598 599 600 601 602 603 604 605 606 607 608 609 610 611 612 |
# File 'proto_docs/google/cloud/bigquery/analyticshub/v1/analyticshub.rb', line 526 class BigQueryDatasetSource include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Resource in this dataset that is selectively shared. # @!attribute [rw] table # @return [::String] # Optional. Format: # For table: # `projects/{projectId}/datasets/{datasetId}/tables/{tableId}` # Example:"projects/test_project/datasets/test_dataset/tables/test_table" # # Note: The following fields are mutually exclusive: `table`, `routine`. If a field in that set is populated, all other fields in the set will automatically be cleared. # @!attribute [rw] routine # @return [::String] # Optional. Format: # For routine: # `projects/{projectId}/datasets/{datasetId}/routines/{routineId}` # Example:"projects/test_project/datasets/test_dataset/routines/test_routine" # # Note: The following fields are mutually exclusive: `routine`, `table`. If a field in that set is populated, all other fields in the set will automatically be cleared. class SelectedResource include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Restricted export policy used to configure restricted export on linked # dataset. # @!attribute [rw] enabled # @return [::Google::Protobuf::BoolValue] # Optional. If true, enable restricted export. # @!attribute [rw] restrict_direct_table_access # @return [::Google::Protobuf::BoolValue] # Optional. If true, restrict direct table access (read # api/tabledata.list) on linked table. # @!attribute [rw] restrict_query_result # @return [::Google::Protobuf::BoolValue] # Optional. If true, restrict export of query result derived from # restricted linked dataset table. class RestrictedExportPolicy include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Represents the state of a replica of a shared dataset. # It includes the geographic location of the replica and # system-computed, output-only fields indicating its replication state and # whether it is the primary replica. # @!attribute [r] location # @return [::String] # Output only. The geographic location where the replica resides. See # [BigQuery locations](https://cloud.google.com/bigquery/docs/locations) # for supported locations. Eg. "us-central1". # @!attribute [r] replica_state # @return [::Google::Cloud::Bigquery::AnalyticsHub::V1::Listing::BigQueryDatasetSource::Replica::ReplicaState] # Output only. Assigned by Analytics Hub based on real BigQuery # replication state. # @!attribute [r] primary_state # @return [::Google::Cloud::Bigquery::AnalyticsHub::V1::Listing::BigQueryDatasetSource::Replica::PrimaryState] # Output only. Indicates that this replica is the primary replica. class Replica include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Replica state of the shared dataset. module ReplicaState # Default value. This value is unused. REPLICA_STATE_UNSPECIFIED = 0 # The replica is backfilled and ready to use. READY_TO_USE = 1 # The replica is unavailable, does not exist, or has not been # backfilled yet. UNAVAILABLE = 2 end # Primary state of the replica. Set only for the primary replica. module PrimaryState # Default value. This value is unused. PRIMARY_STATE_UNSPECIFIED = 0 # The replica is the primary replica. PRIMARY_REPLICA = 1 end end end |
#selected_resources ⇒ ::Array<::Google::Cloud::Bigquery::AnalyticsHub::V1::Listing::BigQueryDatasetSource::SelectedResource>
Returns Optional. Resource in this dataset that is selectively shared. This field is required for data clean room exchanges.
526 527 528 529 530 531 532 533 534 535 536 537 538 539 540 541 542 543 544 545 546 547 548 549 550 551 552 553 554 555 556 557 558 559 560 561 562 563 564 565 566 567 568 569 570 571 572 573 574 575 576 577 578 579 580 581 582 583 584 585 586 587 588 589 590 591 592 593 594 595 596 597 598 599 600 601 602 603 604 605 606 607 608 609 610 611 612 |
# File 'proto_docs/google/cloud/bigquery/analyticshub/v1/analyticshub.rb', line 526 class BigQueryDatasetSource include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Resource in this dataset that is selectively shared. # @!attribute [rw] table # @return [::String] # Optional. Format: # For table: # `projects/{projectId}/datasets/{datasetId}/tables/{tableId}` # Example:"projects/test_project/datasets/test_dataset/tables/test_table" # # Note: The following fields are mutually exclusive: `table`, `routine`. If a field in that set is populated, all other fields in the set will automatically be cleared. # @!attribute [rw] routine # @return [::String] # Optional. Format: # For routine: # `projects/{projectId}/datasets/{datasetId}/routines/{routineId}` # Example:"projects/test_project/datasets/test_dataset/routines/test_routine" # # Note: The following fields are mutually exclusive: `routine`, `table`. If a field in that set is populated, all other fields in the set will automatically be cleared. class SelectedResource include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Restricted export policy used to configure restricted export on linked # dataset. # @!attribute [rw] enabled # @return [::Google::Protobuf::BoolValue] # Optional. If true, enable restricted export. # @!attribute [rw] restrict_direct_table_access # @return [::Google::Protobuf::BoolValue] # Optional. If true, restrict direct table access (read # api/tabledata.list) on linked table. # @!attribute [rw] restrict_query_result # @return [::Google::Protobuf::BoolValue] # Optional. If true, restrict export of query result derived from # restricted linked dataset table. class RestrictedExportPolicy include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Represents the state of a replica of a shared dataset. # It includes the geographic location of the replica and # system-computed, output-only fields indicating its replication state and # whether it is the primary replica. # @!attribute [r] location # @return [::String] # Output only. The geographic location where the replica resides. See # [BigQuery locations](https://cloud.google.com/bigquery/docs/locations) # for supported locations. Eg. "us-central1". # @!attribute [r] replica_state # @return [::Google::Cloud::Bigquery::AnalyticsHub::V1::Listing::BigQueryDatasetSource::Replica::ReplicaState] # Output only. Assigned by Analytics Hub based on real BigQuery # replication state. # @!attribute [r] primary_state # @return [::Google::Cloud::Bigquery::AnalyticsHub::V1::Listing::BigQueryDatasetSource::Replica::PrimaryState] # Output only. Indicates that this replica is the primary replica. class Replica include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Replica state of the shared dataset. module ReplicaState # Default value. This value is unused. REPLICA_STATE_UNSPECIFIED = 0 # The replica is backfilled and ready to use. READY_TO_USE = 1 # The replica is unavailable, does not exist, or has not been # backfilled yet. UNAVAILABLE = 2 end # Primary state of the replica. Set only for the primary replica. module PrimaryState # Default value. This value is unused. PRIMARY_STATE_UNSPECIFIED = 0 # The replica is the primary replica. PRIMARY_REPLICA = 1 end end end |